# Plum SDK

Python SDK for [Plum AI](https://getplum.ai).

## Installation

```bash
pip install plum-sdk
```

## Usage

The Plum SDK allows you to upload training examples along with a system prompt to evaluate and improve your LLM.

### Basic Usage

```python
from plum_sdk import PlumClient, TrainingExample

# Initialize the SDK with your API key
api_key = "YOUR_API_KEY"
plum_client = PlumClient(api_key)

# Create training examples
training_examples = [
    TrainingExample(
        input="What is the capital of France?",
        output="The capital of France is Paris."
    ),
    TrainingExample(
        input="How do I make pasta?",
        output="1. Boil water\n2. Add salt\n3. Cook pasta until al dente"
    )
]

# Define your system prompt
system_prompt = "You are a helpful assistant that provides accurate and concise answers."

# Upload the data
response = plum_client.upload_data(training_examples, system_prompt)
print(response)
```

### Error Handling

The SDK will raise exceptions for non-200 responses:

```python
from plum_sdk import PlumClient
import requests

try:
    plum_client = PlumClient(api_key="YOUR_API_KEY")
    response = plum_client.upload_data(training_examples, system_prompt)
    print(response)
except requests.exceptions.HTTPError as e:
    print(f"Error uploading data: {e}")
```

## API Reference

### PlumClient

#### Constructor
- `api_key` (str): Your Plum API key

#### Methods
- `upload_data(training_examples: List[TrainingExample], system_prompt: str)`: Uploads training examples and system prompt to Plum DB

### TrainingExample

A dataclass representing a single training example:
- `input` (str): The input text
- `output` (str): The output text produced by your LLM